jacinle.utils.env
=================

.. automodule:: jacinle.utils.env

   
   
   

   
   
   

   
   
   .. rubric:: Functions

   .. autosummary::
   
      jac_get_dashdebug_arg
      jac_getenv
      jac_is_debug
      jac_is_verbose
   
   

   
   
   











.. rubric:: Functions

.. autofunction:: jac_get_dashdebug_arg

.. autofunction:: jac_getenv

.. autofunction:: jac_is_debug

.. autofunction:: jac_is_verbose


